.. Cryptomamy_Cryptomamy_kraken_api:

Cryptomamy_kraken_api
=====================

.. image:: https://travis-ci.org/Cryptomamy/Cryptomamy_kraken_api.svg?branch=main
   :alt: Latest Travis continuous integration build
   :target: https://travis-ci.org/Cryptomamy/Cryptomamy_kraken_api

.. image:: https://readthedocs.org/projects/Cryptomamy_kraken_api/badge/
   :alt: Read latest documentation
   :target: https://Cryptomamy_kraken_api.readthedocs.io/

.. image:: https://badge.fury.io/py/Cryptomamy_kraken_api.svg
   :alt: Latest PyPI release
   :target: https://badge.fury.io/py/Cryptomamy_kraken_api

.. image:: https://badges.gitter.im/Cryptomamy_kraken_api/Lobby.svg
   :alt: Development discussion at https://gitter.im/Cryptomamy_kraken_api/Lobby
   :target: https://gitter.im/Cryptomamy_kraken_api/Lobby?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge

Overview
--------

Kraken.com exchange API, Python 3 package.

This package is intentionally as lean as possible, and only provides a minimal interface to the `Kraken`_ cryptocurrency exchange. Intended for developers, not traders.

.. _Kraken: https://kraken.com/

Documentation
-------------

View the `latest documentation`_ or the `stable version`_ online at ReadTheDocs.

The code is documented in docstrings and can be viewed with a text editor.

You can also generate your own documentation with, e.g., `make html` in the `doc` directory. This requires `sphinx` and its `rtd` theme.

For the most up-to-date list of public/private Kraken API methods, see their `API documentation`_.

.. _latest documentation: https://Cryptomamy_kraken_api.readthedocs.io/en/latest/
.. _stable version: https://Cryptomamy_kraken_api.readthedocs.io/en/stable/
.. _API documentation: https://www.kraken.com/help/api
